//
//  ContentView.swift
//  UIWeather
//
//  Created by Joe Gregg on 8/9/22.
//

import SwiftUI

struct TempRange : Decodable {
    let day: Double
    let min: Double?
    let max: Double?
    let night: Double
    let eve: Double
    let morn: Double
}

struct Weather : Decodable {
    let id: Int
    let main: String
    let description: String
    let icon: String
}

struct ForecastDay : Decodable, Identifiable {
    var id : Int { return dt }
    let dt: Int
    let sunrise: Int
    let sunset: Int
    let moonrise: Int
    let moonset: Int
    let moon_phase: Double
    let temp: TempRange
    let feels_like: TempRange
    let pressure: Int
    let humidity: Int
    let dew_point: Double
    let wind_speed: Double
    let wind_deg: Int
    let wind_gust: Double
    let weather: [Weather]
    let clouds: Int
    let pop: Double
    let rain: Double?
    let uvi: Double
}

struct Forecast : Decodable {
    let lat : Double
    let lon : Double
    let timezone: String
    let timezone_offset : Int
    let daily : [ForecastDay]
}

struct ContentView: View {
    @State var forecast : Forecast?
    let formatter = DateFormatter()
    @EnvironmentObject private var lc : LocationInfo
    
    var body: some View {
        NavigationStack {
            List {
                Section(header: Text("\(lc.location.name)")) {
                    if let fc = forecast {
                        ForEach(fc.daily) { day in
                            let interval = TimeInterval(day.dt+fc.timezone_offset)
                            let date = Date(timeIntervalSince1970:interval)
                            ForecastView(fd:day,date:date)
                        }
                    } else {
                        Text("Loading...")
                    }
                }
            }.task {
                await getForecast()
            }.navigationTitle("Weather")
             .navigationBarTitleDisplayMode(.inline)
             .navigationBarItems(
                      trailing: NavigationLink("Settings") { WeatherSettings() }
                      )
        }
    }
    
    func getForecast() async {
        let urlStr = "https://api.openweathermap.org/data/3.0/onecall?lat=\(lc.location.latitude)&lon=\(lc.location.longitude)&APPID=\(Settings.key)&exclude=current,minutely,hourly,alerts&units=imperial"
        guard let url = URL(string: urlStr) else { return }
        do {
            let (data, _) = try await URLSession.shared.data(from: url)
            forecast = try JSONDecoder().decode(Forecast.self, from: data)
        } catch {
            
        }
    }
}

struct ContentView_Previews: PreviewProvider {
    static var previews: some View {
        ContentView().environmentObject(LocationInfo())
    }
}
