//
//  LocationController.swift
//  UIWeather
//
//  Created by Joe Gregg on 8/9/22.
//

import Foundation
import SwiftUI

struct GeoLocation : Codable {
    let zip : String
    let name : String
    let lat : Double
    let lon : Double
    let country : String
}

class LocationInfo : ObservableObject {
    @Published var location : Location
    
    let itemArchiveURL: URL = {
        let documentsDirectories =
            FileManager.default.urls(for: .documentDirectory, in: .userDomainMask)
        let documentDirectory = documentsDirectories.first!
        return documentDirectory.appendingPathComponent("location.plist")
    }()
    
    init() {
        do {
            let data = try Data(contentsOf: itemArchiveURL)
            let unarchiver = PropertyListDecoder()
            let loc = try unarchiver.decode(Location.self, from: data)
            location =  loc
        } catch {
            location = Location()
        }
    }
    
    func saveChanges() {
        let encoder = PropertyListEncoder()
        let data = try! encoder.encode(location)
        try! data.write(to: itemArchiveURL)
    }
    
    func searchLocation(code : String!) async {
        if let zip = code {
            let key = Settings.key
            let urlStr = "https://api.openweathermap.org/geo/1.0/zip?zip=\(zip),US&appid=\(key)"
            guard let url = URL(string: urlStr) else { return }
            do {
                let (data, response) = try await URLSession.shared.data(from: url)
                guard (response as! HTTPURLResponse).statusCode == 200 else { return }
                let result = try JSONDecoder().decode(GeoLocation.self, from: data)
                DispatchQueue.main.async {
                    self.location = Location(zip:zip,latitude:result.lat,longitude:result.lon,name:result.name)
                    self.saveChanges()
                }
            } catch {
                
            }
        }
    }
}
